@@ -1,5 +1,5 @@
 package Text::Autoformat;
-$Text::Autoformat::VERSION = '1.73';
+$Text::Autoformat::VERSION = '1.74';
 use 5.006;
 use strict;
 use warnings;
@@ -264,7 +264,8 @@ sub autoformat  # ($text, %args)
             }
             else
             {
-    my $extraspace = length($line->{raw}) - length($line->{text}) - $firstfrom;
+                my $extraspace = length($line->{raw}) - length($line->{text}) - $firstfrom;
+                $extraspace = 0 if $extraspace < 0;
                 $paras[-1]->{text} .= "\n" . q{ }x$extraspace . $line->{text};
                 $paras[-1]->{raw} .= "\n" . $line->{raw};
             }
@@ -419,12 +420,12 @@ sub autoformat  # ($text, %args)
     for my $para ( @paras )
     {
         if ($para->{empty}) {
-        $gap += 1 + ($para->{text} =~ tr/\n/\n/);
+            $gap += 1 + ($para->{text} =~ tr/\n/\n/);
         }
         if ($para->{ignore}) {
-            $text .= (!$para->{empty} ? "\n"x($args{gap}-$gap) : "") ;
-        $text .= $para->{raw};
-        $text .= "\n" unless $para->{raw} =~ /\n\z/;
+            $text .= (!$para->{empty} ? "\n"x($args{gap}-$gap > 0 ? ($args{gap}-$gap) : 0) : "") ;
+            $text .= $para->{raw};
+            $text .= "\n" unless $para->{raw} =~ /\n\z/;
         }
         else {
             my $leftmargin = $args{left} ? " "x($args{left}-1)
@@ -455,7 +456,7 @@ sub autoformat  # ($text, %args)
                      :                                     '['x$tlen
                          );
             my $tryformat = "$format$tfield";
-            $newtext = (!$para->{empty} ? "\n"x($args{gap}-$gap) : "") 
+            $newtext = (!$para->{empty} ? "\n"x($args{gap} > $gap ? ($args{gap}-$gap) : 0) : "") 
                      . form( { squeeze=>$args{squeeze}, trim=>1,
                        break=>$args{break},
                        fill => !(!($args{expfill}
@@ -1258,7 +1259,16 @@ can change that default using the 'tabspace' option:
 
 =head1 SEE ALSO
 
-The Text::Reform module
+L<Text::Reform> - provides functions for manual text wrapping and reformatting.
+
+L<Text::Aligner> - provides a single function for justifying strings
+according to various styles.
+
+L<Text::Format> - a class that provides methods for formatting
+text in various ways.
+
+L<Data::Formatter::Text> - format various Perl data structures as text,
+in different ways according to the type of data.
 
 =head1 REPOSITORY
 
